# Generated by Django 3.1.7 on 2021-02-25 23:21

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Region',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=254, verbose_name='Nome')),
                ('acronym', models.CharField(max_length=2, verbose_name='Sigla')),
            ],
            options={
                'verbose_name': 'Região',
                'verbose_name_plural': 'Regiões',
            },
        ),
        migrations.CreateModel(
            name='State',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=254, verbose_name='Nome')),
                ('acronym', models.CharField(max_length=2, verbose_name='Sigla')),
                ('region', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='djangoaddressesapp.region', verbose_name='Região')),
            ],
            options={
                'verbose_name': 'Estado',
                'verbose_name_plural': 'Estados',
            },
        ),
        migrations.CreateModel(
            name='City',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=254, verbose_name='Nome')),
                ('state', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='djangoaddressesapp.state', verbose_name='')),
            ],
            options={
                'verbose_name': 'Município',
                'verbose_name_plural': 'Municípios',
            },
        ),
        migrations.CreateModel(
            name='Address',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('complement', models.CharField(blank=True, max_length=254, null=True, verbose_name='Complemento')),
                ('zipcode', models.CharField(blank=True, max_length=8, null=True, verbose_name='CEP')),
                ('district', models.CharField(max_length=254, verbose_name='Bairro')),
                ('address', models.CharField(max_length=254, verbose_name='Endereço')),
                ('number', models.IntegerField(verbose_name='Número')),
                ('city', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='djangoaddressesapp.city', verbose_name='Município')),
                ('state', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='djangoaddressesapp.state', verbose_name='Estado')),
            ],
            options={
                'verbose_name': 'Endereço',
                'verbose_name_plural': 'Endereços',
            },
        ),
    ]
